==> jc-1.4.0.tar.gz: soot/jimple/toolkits/scalar/pre/DelayabilityAnalysis.h <==
// public class soot.jimple.toolkits.scalar.pre.DelayabilityAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class dee4c63e11feecc5 soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis
// @dep_class 670b274dd70b8d71 soot_toolkits_scalar_ForwardFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_ForwardFlowAnalysis

#include "soot/toolkits/scalar/ForwardFlowAnalysis.h"

#ifndef _JC_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis_H_
#define _JC_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;
struct _jc_soot_toolkits_scalar_BoundedFlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_refs	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$refs	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$nonrefs	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vmethods	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtable	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtype	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$_init$6a8aa0b005ae6ff6(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$_init$4826a3d6f9aeabec(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$copy$0585c1f937996187(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *);
extern void _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$merge$37b91166a64cb493(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method_info$copy$0585c1f937996187;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method_info$newInitialFlow$8126aa62e2c0e28e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vmethods {
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *);
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardFlowAnalysis;
	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vmethods	soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_refs {
	struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object	*earliest;
	struct _jc_object	*unitToKillValue;
	struct _jc_object	*set;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$refs {
    _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_refs	soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_nonrefs	soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object {
	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtype _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/scalar/pre/DelayabilityAnalysis.h <==
// public class soot.jimple.toolkits.scalar.pre.DelayabilityAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class dee4c63e11feecc5 soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis
// @dep_class 670b274dd70b8d71 soot_toolkits_scalar_ForwardFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_ForwardFlowAnalysis

#include "soot/toolkits/scalar/ForwardFlowAnalysis.h"

#ifndef _JC_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis_H_
#define _JC_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;
struct _jc_soot_toolkits_scalar_BoundedFlowSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_refs	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_nonrefs	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$refs	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$refs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$nonrefs	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$nonrefs;
typedef struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object;

typedef const struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vmethods	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vmethods;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtable	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtable;
typedef const struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtype	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$_init$6a8aa0b005ae6ff6(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$_init$4826a3d6f9aeabec(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_object *, struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$copy$0585c1f937996187(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$entryInitialFlow$8b63b3b8f54d43fb(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$flowThrough$087b926607d6a11b(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$merge$37b91166a64cb493(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method$newInitialFlow$8126aa62e2c0e28e(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method_info$copy$0585c1f937996187;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method_info$entryInitialFlow$8b63b3b8f54d43fb;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method_info$flowThrough$087b926607d6a11b;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method_info$merge$37b91166a64cb493;
extern _jc_method _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$method_info$newInitialFlow$8126aa62e2c0e28e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vmethods {
	void	(*copy$0585c1f937996187)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*entryInitialFlow$8b63b3b8f54d43fb)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *) _JC_JCNI_ATTR;
	void	(*flowThrough$087b926607d6a11b)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*merge$37b91166a64cb493)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*newInitialFlow$8126aa62e2c0e28e)(_jc_env *, struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardFlowAnalysis;
	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vmethods	soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis;
};

// Vtype
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_refs {
	struct _jc_soot_jimple_toolkits_scalar_pre_EarliestnessComputation$object	*earliest;
	struct _jc_object	*unitToKillValue;
	struct _jc_object	*set;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$refs {
    _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_refs	soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$sub_nonrefs	soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$object {
	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtype	*vtype;
	_jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$vtype _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis$class_object;

#endif	/* _JC_soot_jimple_toolkits_scalar_pre_DelayabilityAnalysis_H_ */
